Struct amazon_sp_reports::models::report_schedule::ReportSchedule
source · [−]pub struct ReportSchedule {
pub report_schedule_id: String,
pub report_type: String,
pub marketplace_ids: Option<Vec<String>>,
pub report_options: Option<HashMap<String, String>>,
pub period: String,
pub next_report_creation_time: Option<String>,
}Expand description
ReportSchedule : Detailed information about a report schedule.
Fields
report_schedule_id: StringThe identifier for the report schedule. This identifier is unique only in combination with a seller ID.
report_type: StringThe report type.
marketplace_ids: Option<Vec<String>>A list of marketplace identifiers. The report document’s contents will contain data for all of the specified marketplaces, unless the report type indicates otherwise.
report_options: Option<HashMap<String, String>>Additional information passed to reports. This varies by report type.
period: StringAn ISO 8601 period value that indicates how often a report should be created.
next_report_creation_time: Option<String>The date and time when the schedule will create its next report, in ISO 8601 date time format.
Implementations
sourceimpl ReportSchedule
impl ReportSchedule